import React from 'react';
import { useStaticQuery, graphql } from 'gatsby';
import Fade from 'react-reveal/Fade';
import Zoom from 'react-reveal/Zoom';
import Masonry from 'react-masonry-component';
import { Icon } from 'react-icons-kit';
import { chevronRight } from 'react-icons-kit/feather/chevronRight';

import Container from 'common/src/components/UI/Container';
import Image from 'common/src/components/Image';
import Link from 'common/src/components/Link';
import SectionHeading from '../SectionHeading';
import Section, { ContentWrapper, BlogPost } from './news.style';

const masonryOptions = {
  originTop: false,
};

const News = () => {
  const data = useStaticQuery(graphql`
    query {
      agencyDigitalJson {
        newsFeed {
          id
          title
          desc
          link
          image {
            childImageSharp {
              fluid(quality: 100) {
                ...GatsbyImageSharpFluid
              }
            }
          }
        }
      }
    }
  `);
  const newsFeed = data.agencyDigitalJson.newsFeed;
  return (
    <Section id="blog">
      <Container>
        <Zoom>
          <SectionHeading
            slogan="Ideal solutions for you"
            title="Go beyond ultimate features"
          />
        </Zoom>
        <ContentWrapper>
          <Masonry className="masonryGrid" options={masonryOptions}>
            {newsFeed.map(news => {
              return (
                <Fade key={news.id} up delay={100 * news.id}>
                  <BlogPost>
                    <figure>
                      <Image
                        src={news.image.childImageSharp.fluid.src}
                        alt={news.title}
                      />
                    </figure>
                    <h4>{news.title}</h4>
                    {news.desc && <p>{news.desc}</p>}
                    {news.link && (
                      <Link href={news.link} className="learnMore">
                        Learn More <Icon icon={chevronRight} />
                      </Link>
                    )}
                  </BlogPost>
                </Fade>
              );
            })}
          </Masonry>
        </ContentWrapper>
      </Container>
    </Section>
  );
};

export default News;
